@@ -1,6 +1,6 @@
 /***************************************************************************
  *   Copyright (C) 2004 by Paulo Moura Guedes                              *
- *   moura@kdewebdev.org                                                        *
+ *   moura@kdewebdev.org                                                   *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -15,38 +15,46 @@
  *   You should have received a copy of the GNU General Public License     *
  *   along with this program; if not, write to the                         *
  *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.             *
+ *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
 
 #include <kapplication.h>
 #include <kdebug.h>
 #include <klocale.h>
 #include <khtml_part.h>
+#include <kprotocolmanager.h>
 
 #include <qstring.h>
 #include <qvaluevector.h>
+#include <qdom.h>
 
 #include <iostream>
 #include <unistd.h>
 
 #include "searchmanager.h"
 #include "../parser/mstring.h"
+#include "../cfg/klsconfig.h"
 
 
 SearchManager::SearchManager(int max_simultaneous_connections, int time_out,
                              QObject *parent, const char *name)
         : QObject(parent, name),
-        max_simultaneous_connections_(max_simultaneous_connections),
+        max_simultaneous_connections_(max_simultaneous_connections), has_document_root_(false), 
         depth_(-1), current_depth_(0), external_domain_depth_(0),
         current_node_(0), current_index_(0), links_being_checked_(0),
         finished_connections_(max_simultaneous_connections_),
         maximum_current_connections_(-1), general_domain_(false),
         checked_general_domain_(false), time_out_(time_out), current_connections_(0),
-        canceled_(false), searching_(false), checked_links_(0), ignored_links_(0),
+        send_identification_(true), canceled_(false), searching_(false), checked_links_(0), ignored_links_(0),
         check_parent_dirs_(true), check_external_links_(true), check_regular_expressions_(false),
         number_of_level_links_(0), number_of_links_to_check_(0)
 {
     root_.setIsRoot(true);
+
+    if (KLSConfig::userAgent().isEmpty()) {
+        KLSConfig::setUserAgent(KProtocolManager::defaultUserAgent());
+    }
+    user_agent_ = KLSConfig::userAgent();
 }
 
 void SearchManager::reset()
@@ -70,7 +78,11 @@ void SearchManager::reset()
     current_connections_ = 0;
     canceled_ = false;
     searching_ = false;
-    checked_links_ = 0;
+    checked_links_ = 0;    
+    if(KLSConfig::userAgent().isEmpty()) {
+        KLSConfig::setUserAgent(KProtocolManager::defaultUserAgent());
+    }
+    user_agent_ = KLSConfig::userAgent();
 
     removeHtmlParts();
 }
@@ -182,7 +194,7 @@ void SearchManager::checkRoot()
     connect(checker, SIGNAL(transactionFinished(const LinkStatus *, LinkChecker *)),
             this, SLOT(slotRootChecked(const LinkStatus *, LinkChecker *)));
     /*
-    	connect(checker, SIGNAL(jobFinnished(LinkChecker *)),
+        connect(checker, SIGNAL(jobFinnished(LinkChecker *)),
                 this, SLOT(slotLinkCheckerFinnished(LinkChecker *)));
     */
     checker->check();
@@ -190,7 +202,9 @@ void SearchManager::checkRoot()
 
 void SearchManager::slotRootChecked(const LinkStatus * link, LinkChecker * checker)
 {
-    kdDebug(23100) <<  "SearchManager::slotRootChecked" << endl;
+    kdDebug(23100) <<  "SearchManager::slotRootChecked:" << endl;
+    kdDebug(23100) <<  link->absoluteUrl().url() << " -> " << 
+            LinkStatus::lastRedirection(&root_)->absoluteUrl().url() << endl;
 
     Q_ASSERT(checked_links_ == 0);
     Q_ASSERT(search_results_.size() == 0);
@@ -225,7 +239,7 @@ void SearchManager::slotRootChecked(const LinkStatus * link, LinkChecker * check
         }
         else
         {
-            kdDebug(23100) <<  "Search Finished! (SearchManager::slotRootChecked)#1" << endl;
+            kdDebug(23100) <<  "SearchManager::slotRootChecked#1" << endl;
             finnish();
         }
     }
@@ -233,7 +247,7 @@ void SearchManager::slotRootChecked(const LinkStatus * link, LinkChecker * check
     else
     {
         Q_ASSERT(search_results_.size() == 0);
-        kdDebug(23100) <<  "Search Finished! (SearchManager::slotRootChecked)#2" << endl;
+        kdDebug(23100) <<  "SearchManager::slotRootChecked#2" << endl;
         finnish();
     }
 
@@ -260,7 +274,7 @@ vector<LinkStatus*> SearchManager::children(LinkStatus* link)
         if(node->url().isEmpty())
             url = "";
         else
-            url = Url::normalizeUrl( node->url(), *link );
+            url = Url::normalizeUrl(node->url(), *link, documentRoot().path());
 
         if( (node->isLink() &&
                 checkable(url, *link) &&
@@ -280,11 +294,10 @@ vector<LinkStatus*> SearchManager::children(LinkStatus* link)
             //ls->setIsLocalRestrict(localDomain(url));
             ls->setIsLocalRestrict(ls->local()); // @todo clean this nonsense
 
-            if(!validUrl(url))
+            if(!validUrl(url)) {
                 ls->setMalformed(true);
-
-            if(ls->malformed())
-                ls->setErrorOccurred(true);
+                ls->setErrorOccurred(true); 
+            }
 
             ls->setOnlyCheckHeader(onlyCheckHeader(ls));
 
@@ -319,16 +332,19 @@ bool SearchManager::existUrl(KURL const& url, KURL const& url_parent) const
             for(uint l = 0; l != (search_results_[i])[j].size(); ++l)
             {
                 LinkStatus* tmp = search_results_[i][j][l];
-                Q_ASSERT(tmp);
+                Q_ASSERT(tmp);                
                 if(tmp->absoluteUrl() == url)
                 { // URL exists
                     QValueVector<KURL> referrers(tmp->referrers());
 
+                    // Add new referrer
                     for(uint i = 0; i != referrers.size(); ++i)
+                    {
                         if(referrers[i] == url_parent)
                             return true;
-
+                    }
                     tmp->addReferrer(url_parent);
+                    
                     return true;
                 }
             }
@@ -475,7 +491,7 @@ void SearchManager::checkLinksSimultaneously(vector<LinkStatus*> const& links)
         if(ls->malformed())
         {
             Q_ASSERT(ls->errorOccurred());
-            Q_ASSERT(ls->error() == i18n( "Malformed" ));
+            Q_ASSERT(ls->status() == LinkStatus::MALFORMED);
 
             ls->setChecked(true);
             slotLinkChecked(ls, 0);
@@ -487,6 +503,7 @@ void SearchManager::checkLinksSimultaneously(vector<LinkStatus*> const& links)
             ls->setIgnored(true);
             ls->setErrorOccurred(true);
             ls->setError(i18n( "Javascript not supported" ));
+            ls->setStatus(LinkStatus::NOT_SUPPORTED);
             ls->setChecked(true);
             slotLinkChecked(ls, 0);
         }
@@ -497,6 +514,7 @@ void SearchManager::checkLinksSimultaneously(vector<LinkStatus*> const& links)
                     ls->setIgnored(true);
                     ls->setErrorOccurred(true);
                     ls->setError(i18n("Protocol %1 not supported").arg(protocol));
+                    ls->setStatus(LinkStatus::MALFORMED);
                     ls->setChecked(true);
                     slotLinkChecked(ls, 0);
                 }
@@ -509,7 +527,7 @@ void SearchManager::checkLinksSimultaneously(vector<LinkStatus*> const& links)
             connect(checker, SIGNAL(transactionFinished(const LinkStatus *, LinkChecker *)),
                     this, SLOT(slotLinkChecked(const LinkStatus *, LinkChecker *)));
             /*
-            			connect(checker, SIGNAL(jobFinnished(LinkChecker *)),
+                        connect(checker, SIGNAL(jobFinnished(LinkChecker *)),
                                 this, SLOT(slotLinkCheckerFinnished(LinkChecker *)));
             */
             checker->check();
@@ -519,7 +537,9 @@ void SearchManager::checkLinksSimultaneously(vector<LinkStatus*> const& links)
 
 void SearchManager::slotLinkChecked(const LinkStatus * link, LinkChecker * checker)
 {
-    //kdDebug(23100) <<  "SearchManager::slotLinkChecked -> " << link->absoluteUrl().url() << endl;
+    kdDebug(23100) <<  "SearchManager::slotLinkChecked:" << endl;
+//     kdDebug(23100) <<  link->absoluteUrl().url() << " -> " << 
+//             LinkStatus::lastRedirection((const_cast<LinkStatus*> (link)))->absoluteUrl().url() << endl;
 
     Q_ASSERT(link);
     emit signalLinkChecked(link, checker);
@@ -579,7 +599,7 @@ void SearchManager::addLevel()
             }
 
             emit signalAddingLevelProgress();
-            kapp->processEvents();
+//             kapp->processEvents();
         }
     }
     if( (search_results_[search_results_.size() - 1]).size() == 0 )
@@ -678,8 +698,8 @@ bool SearchManager::localDomain(KURL const& url) const
 */
 
 /**
-	The same as SearchManager::localDomain(), but only for http or https.
-	http://linkstatus.paradigma.co.pt != http://paradigma.co.pt
+    The same as SearchManager::localDomain(), but only for http or https.
+    http://linkstatus.paradigma.co.pt != http://paradigma.co.pt
 */
 /*
 bool SearchManager::isLocalRestrict(KURL const& url) const
@@ -823,4 +843,74 @@ void SearchManager::removeHtmlParts()
     html_parts_.clear();
 }
 
+void SearchManager::save(QDomElement& element) const
+{
+    // <url>
+    QDomElement child_element = element.ownerDocument().createElement("url");
+    child_element.appendChild(element.ownerDocument().createTextNode(root_.absoluteUrl().prettyURL()));
+    element.appendChild(child_element);
+
+    // <recursively>
+    bool recursively = searchMode() == domain || depth_ > 0;
+    child_element = element.ownerDocument().createElement("recursively");
+    child_element.appendChild(element.ownerDocument().createTextNode(recursively ? "true" : "false"));
+    element.appendChild(child_element);
+
+    // <depth>
+    child_element = element.ownerDocument().createElement("depth");
+    child_element.appendChild(element.ownerDocument().
+            createTextNode(searchMode() == domain ? QString("Unlimited") : QString::number(depth_)));
+    element.appendChild(child_element);
+
+    // <check_parent_folders>
+    child_element = element.ownerDocument().createElement("check_parent_folders");
+    child_element.appendChild(element.ownerDocument().
+            createTextNode(checkParentDirs() ? "true" : "false"));
+    element.appendChild(child_element);
+
+    // <check_external_links>
+    child_element = element.ownerDocument().createElement("check_external_links");
+    child_element.appendChild(element.ownerDocument().
+            createTextNode(checkExternalLinks() ? "true" : "false"));
+    element.appendChild(child_element);
+
+    // <check_regular_expression>
+    child_element = element.ownerDocument().createElement("check_regular_expression");
+    child_element.setAttribute("check", checkRegularExpressions() ? "true" : "false");
+    if(checkRegularExpressions())
+        child_element.appendChild(element.ownerDocument().
+                createTextNode(reg_exp_.pattern()));
+    element.appendChild(child_element);
+    
+    child_element = element.ownerDocument().createElement("link_list");
+    element.appendChild(child_element);
+    
+    for(uint i = 0; i != search_results_.size(); ++i)
+    {
+        for(uint j = 0; j != search_results_[i].size() ; ++j)
+        {
+            for(uint l = 0; l != (search_results_[i])[j].size(); ++l)
+            {
+                LinkStatus* ls = ((search_results_[i])[j])[l];
+                if(ls->checked())
+                    ls->save(child_element);
+            }
+        }
+    } 
+}
+
+QString SearchManager::toXML() const
+{
+    QDomDocument doc;
+    doc.appendChild(doc.createProcessingInstruction( "xml", 
+                                       "version=\"1.0\" encoding=\"UTF-8\""));
+    
+    QDomElement root = doc.createElement("klinkstatus");
+    doc.appendChild(root);
+
+    save(root);
+    
+    return doc.toString(4);
+}
+
 #include "searchmanager.moc"
