@@ -296,6 +296,8 @@ void SpecialInformation::registerSpecials()
   insert(DCOP::clear, "clear(QString widget)",
          i18n("Removes all content from the widget."), 1);
   insertAlias(DCOP::clear, "clearList");
+  insertInternal(DCOP::columnCount, "columnCount(QString widget)", 
+        i18n("Get the column count"), 1);
   insert(DCOP::count, "count(QString widget)",
          i18n("Returns number of items in a widget such as combobox or listbox."), 1);
   insert(DCOP::currentColumn, "currentColumn(QString widget)", 
@@ -305,9 +307,9 @@ void SpecialInformation::registerSpecials()
   insert(DCOP::currentRow, "currentRow(QString widget)", 
          i18n("Returns index of current row."), 1);
   insert(DCOP::execute, "execute(QString widget)", 
-         i18n("Executes the script associated with the widget. With the new parser the execute method can take one or more arguments."), 1, 6);
-  insert(DCOP::findItem, "findItem(QString widget, QString item)",
-         i18n("Returns the index of an item with the given text."), 2);
+         i18n("Executes the script associated with the widget. With the new parser the execute method can take one or more arguments."), 1, 9);
+  insert(DCOP::findItem, "findItem(QString widget, QString item, int column, bool CaseSensitive, bool ExactMatch)",
+         i18n("Returns the index of an item with the given text. Defaults to case sensitive. Matching can be an exact match or match if it contains the string. Only the first argument is requred. If no column is given it will search the first by default."), 2, 5);
   insert(DCOP::insertColumn, "insertColumn(QString widget, int column, int count)",
          i18n("Inserts new column (or <i>count</i> columns) at <i>column</i> position."), 2);
   insert(DCOP::insertItem, "insertItem(QString widget, QString item, int index)",
@@ -325,7 +327,7 @@ void SpecialInformation::registerSpecials()
   insert(DCOP::itemPath, "itemPath(QString widget, int index)",
          i18n("Returns the slash-separated path to the given item in the tree."), 2);
   insert(DCOP::removeColumn, "removeColumn(QString widget, int column, int count)",
-         i18n("Removes the column (or <i>count</i> consecutive columns) with the given index."), 3);
+         i18n("Removes the column (or <i>count</i> consecutive columns) with the given index."), 2, 3);
   insert(DCOP::removeItem, "removeItem(QString widget, int index)",
          i18n("Removes the item with the given index."), 2);
   insertAlias(DCOP::removeItem, "removeListItem");
@@ -373,6 +375,10 @@ void SpecialInformation::registerSpecials()
      i18n("Returns type(class) of widget."), 1);
   insert(DCOP::setEditable, "setEditable(QString widget, bool editable)", 
      i18n("Makes the widget editable or read only, depending on the editable argument."), 2);
+  insertInternal(DCOP::geometry, "geometry(QString widget)", 
+     i18n("Return the widget's geometry as <i>x y w h</i>. This is useful for positioning a created widget."), 1);
+  insertInternal(DCOP::hasFocus, "hasFocus(QString widget)", 
+     i18n("Returns true if the widget has focus."), 1);
 
   insertGroup(Group::Slots, i18n("Slots"), "");
 
@@ -510,6 +516,8 @@ void SpecialInformation::registerSpecials()
     i18n("Returns given section of a string."), 1);
   insert(String::args, "args(QString string, QString arg1, QString arg2, QString arg3)", 
     i18n("Returns the given string with %1, %2, %3 replaced with <i>arg1</i>, <i>arg2</i>, <i>arg3</i> accordingly."), 2);
+  insert(String::round, "round(QString Number, int Digits)", 
+    i18n("Round a floating point number by x digits."), 2);
 
   insertInternal(String::toInt, "toint(QString string, QString default)",
     i18n("Convert a string to an integer. If not possible use the default value"), 1, 2);
@@ -517,12 +525,14 @@ void SpecialInformation::registerSpecials()
     i18n("Convert a string to a double precision floating point value. If not possible use the default value"), 1, 2);
 
   insertGroup(Group::File, "File", "file");
-  insert(File::read, "read(QString)", 
+  insert(File::read, "read(QString file)", 
     i18n("Returns content of given file."), 1);
   insert(File::write, "write(QString file, QString string)", 
     i18n("Writes given string to a file."), 2);
   insert(File::append, "append(QString file, QString string)", 
     i18n("Appends given string to the end of a file."), 2);
+  insert(File::exists, "exists(QString file)", 
+    i18n("Checks to see if file exists."), 1);
   
   insertGroup(Group::Input, "Input", "input");
   insert(Input::color, "color(QString defaultColor)", i18n("Shows color dialog. Returns color in #RRGGBB format. Defaults to the parameter, if specified."), 0, 1);
