@@ -55,6 +55,20 @@ static ParseNode f_stringContains(Parser*, const ParameterList& params)
   return params[0].toString().contains(params[1].toString());
 }
 
+static ParseNode f_stringCompare(Parser*, const ParameterList& params)
+{
+  int result = QString::compare(params[0].toString(),params[1].toString());
+  if (result < 0)
+  {
+    result = -1;
+  } else
+  if (result > 0)
+  {
+    result = 1;
+  }
+  return result;
+}
+
 static ParseNode f_stringFind(Parser*, const ParameterList& params)
 {
   return params[0].toString().find(params[1].toString(), params.count() == 3 ? params[2].toInt() : 0);
@@ -147,6 +161,12 @@ static ParseNode f_return(Parser* p, const ParameterList& params)
   return params[0];
 }
 
+static ParseNode f_stringRound(Parser*, const ParameterList& params)
+{
+  QString s;
+  s.sprintf("%."+params[1].toString()+"f", params[0].toDouble());
+  return s;
+}
 
 /******************* Debug function ********************************/
 static ParseNode f_debug(Parser*, const ParameterList& params)
@@ -206,6 +226,14 @@ static ParseNode f_fileAppend(Parser*, const ParameterList& params)
   return 1;
 }
 
+static ParseNode f_fileExists(Parser*, const ParameterList& params)
+{
+  QFile file(params[0].toString());
+  if (!file.exists())
+    return 0;
+  else
+    return 1;
+}
 
 static ParseNode f_executeSlot(Parser* parser, const ParameterList& params)
 {
@@ -883,6 +911,7 @@ void ParserData::registerStandardFunctions()
 {
   registerFunction("str_length", Function(&f_stringLength, ValueInt, ValueString));
   registerFunction("str_contains", Function(&f_stringContains, ValueInt, ValueString, ValueString));
+  registerFunction("str_compare", Function(&f_stringCompare, ValueInt, ValueString, ValueString));
   registerFunction("str_find", Function(&f_stringFind, ValueInt, ValueString, ValueString, ValueInt, 2));
   registerFunction("str_findrev", Function(&f_stringFindRev, ValueInt, ValueString, ValueString, ValueInt, 2));
   registerFunction("str_left", Function(&f_stringLeft, ValueString, ValueString, ValueInt));
@@ -898,12 +927,14 @@ void ParserData::registerStandardFunctions()
   registerFunction("str_isempty", Function(&f_stringIsEmpty, ValueInt, ValueString));
   registerFunction("str_toint", Function(&f_stringToInt, ValueString, ValueInt, 1));
   registerFunction("str_todouble", Function(&f_stringToDouble, ValueString, ValueDouble, 1));
+  registerFunction("str_round", Function(&f_stringRound, ValueInt, ValueDouble, ValueInt, 2));
   registerFunction("return", Function(&f_return, ValueNone, ValueString, 1, 1));
   registerFunction("debug", Function(&f_debug, ValueNone, ValueString, 1, 100));
   registerFunction("echo", Function(&f_echo, ValueNone, ValueString, 1, 100));
   registerFunction("file_read", Function(&f_fileRead, ValueString, ValueString, 1, 1));
   registerFunction("file_write", Function(&f_fileWrite, ValueInt, ValueString, ValueString, 2, 100));
   registerFunction("file_append", Function(&f_fileAppend, ValueInt, ValueString, ValueString, 2, 100));
+  registerFunction("file_exists", Function(&f_fileExists, ValueString, ValueString, 1, 1));
   registerFunction("internalDcop", Function(&f_internalDcop, ValueString, ValueString, ValueString, 2, 100));
   registerFunction("executeSlot", Function(&f_executeSlot, ValueString, ValueString, ValueString, 2, 100));
   registerFunction("createWidget", Function(&f_createWidget, ValueString, ValueString, ValueString, 3, 100));
