@@ -21,6 +21,7 @@
 #include <qstringlist.h>
 #include <qevent.h>
 #include <qdialog.h>
+#include <qpoint.h>
 
 /* OTHER INCLUDES */
 #include <specials.h>
@@ -36,10 +37,15 @@ Dialog::Dialog(QWidget *a_parent, const char *a_name, bool a_modal, int a_flags)
   states << "destroy";
   setStates(states);
   setDisplayStates(states);
+  m_useShebang = false;
+  m_shebang = "#!/usr/bin/kmdr-executor";
+  m_firstShow = true;
 }
 
 Dialog::~Dialog()
 {
+  if (!inEditor)
+    destroy();
 }
 
 QString Dialog::currentState() const
@@ -54,12 +60,13 @@ bool Dialog::isKommanderWidget() const
 
 bool Dialog::useInternalParser() const
 {
-  return KommanderWidget::useInternalParser; 
+  return m_useInternalParser; 
 }
 
 void Dialog::setUseInternalParser(bool b) 
 {
   KommanderWidget::useInternalParser = b; 
+  m_useInternalParser = b;
 }
 
 
@@ -123,15 +130,26 @@ void Dialog::exec()
 
 void Dialog::show()
 {
-  QDialog::show();
-  if (!inEditor)
-    initialize();
+//if the dialog is embedded in a KPart, the show can be called many times.
+//to avoid re-init and sending signals we don't want, in that case call only the
+//QWidget's show method to show the widgets, but don't do any QDialog specific 
+//task
+  if (!m_firstShow) 
+  {
+    QWidget::show();
+  } else
+  {
+    QDialog::show();
+    if (!inEditor)
+      initialize();
+    m_firstShow = false;
+  }
 }
 
 void Dialog::done(int r)
 {
-  if (!inEditor)
-    destroy();
+/*  if (!inEditor)
+    destroy();*/
   QDialog::done(r);  
 }
 
@@ -150,9 +168,16 @@ void Dialog::keyPressEvent( QKeyEvent *e )
   
 }
 
+void Dialog::contextMenuEvent( QContextMenuEvent * e )
+{
+  QDialog::contextMenuEvent( e );
+  QPoint p = e->globalPos();
+  emit contextMenuRequested(p.x(), p.y());
+}
+
 bool Dialog::isFunctionSupported(int f)
 {
-  return f == DCOP::text || f == DCOP::setText;
+  return f == DCOP::text || f == DCOP::setText || f == DCOP::geometry;
 }
 
 QString Dialog::handleDCOP(int function, const QStringList& args)
@@ -163,6 +188,9 @@ QString Dialog::handleDCOP(int function, const QStringList& args)
     case DCOP::setText:
       setWidgetText(args[0]);
       break;
+    case DCOP::geometry:
+      return QString::number(this->x())+" "+QString::number(this->y())+" "+QString::number(this->width())+" "+QString::number(this->height());
+      break;
     default:
       return KommanderWidget::handleDCOP(function, args);
   }
