@@ -96,7 +96,14 @@ bool ListBox::isFunctionSupported(int f)
   return f == DCOP::text || f == DCOP::setText || f == DCOP::selection || f == DCOP::setSelection ||
     f == DCOP::insertItems || f == DCOP::insertItem || f == DCOP::removeItem || f == DCOP::clear ||
     f == DCOP::currentItem || f == DCOP::setCurrentItem || f == DCOP::item || f == DCOP::addUniqueItem ||
-      f == DCOP::findItem || f == DCOP::setPixmap || f == DCOP::count;
+      f == DCOP::findItem || f == DCOP::setPixmap || f == DCOP::count || f == DCOP::geometry || f == DCOP::hasFocus;
+}
+
+void ListBox::contextMenuEvent( QContextMenuEvent * e )
+{
+  e->accept();
+  QPoint p = e->globalPos();
+  emit contextMenuRequested(p.x(), p.y());
 }
 
 
@@ -152,7 +159,7 @@ QString ListBox::handleDCOP(int function, const QStringList& args)
       if (index >= 0 && index < (int)count())
         return item(index)->text();
       else
-        return QString::null;
+        return QString();
     }
     case DCOP::addUniqueItem:
       if (!findItem(args[0], Qt::ExactMatch))
@@ -165,6 +172,7 @@ QString ListBox::handleDCOP(int function, const QStringList& args)
       if (!found) found = findItem(args[0], Qt::Contains);
       if (found)
         return QString::number(index(found));
+      else return QString::number(-1);
       break;
     }
     case DCOP::setPixmap:
@@ -189,10 +197,19 @@ QString ListBox::handleDCOP(int function, const QStringList& args)
         strings += item(i)->text();
       return strings.join("\n");
     }
+    case DCOP::geometry:
+    {
+      QString geo = QString::number(this->x())+" "+QString::number(this->y())+" "+QString::number(this->width())+" "+QString::number(this->height());
+      return geo;
+      break;
+    }
+    case DCOP::hasFocus:
+      return QString::number(this->hasFocus());
+      break;
     default:
       return KommanderWidget::handleDCOP(function, args);
   }
-  return QString::null;
+  return QString();
 }
 
 #include "listbox.moc"
