@@ -522,7 +522,7 @@ void XsldbgEvent::handleGlobalVariableItem(XsldbgEventData *eventData, const  vo
 
 
 
-	if (item->comp && item->comp->inst && item->comp->inst->doc){
+	if (item->computed && item->comp && item->comp->inst && item->comp->inst->doc){
 	  fileName = XsldbgDebuggerBase::fromUTF8FileName(item->comp->inst->doc->URL);
 	  lineNumber= xmlGetLineNo(item->comp->inst);
 	}
@@ -566,7 +566,7 @@ void XsldbgEvent::handleLocalVariableItem(XsldbgEventData *eventData, const  voi
 	  name = (XsldbgDebuggerBase::fromUTF8FileName(item->nameURI)).append(":");
 	name.append(XsldbgDebuggerBase::fromUTF8(item->name));
 
-	if (item->comp && item->comp->inst){
+	if (item->computed && item->comp && item->comp->inst){
 	  varXmlNode = item->comp->inst;
 
 	  /* try to find out what template this variable belongs to */
