@@ -490,7 +490,7 @@ xsltProcess(xmlDocPtr doc, xsltStylesheetPtr cur)
 			    /* Indicate how long it took to save to file */
 			    endTimer(i18n("Saving result"));
 		    } else {
-			xsldbgGenericErrorFunc(i18n("Warning: Unsupported, non-standard output method %1.\n").arg((char*)cur->method));
+			xsldbgGenericErrorFunc(i18n("Warning: Unsupported, non-standard output method %1.\n").arg(xsldbgText(cur->method)));
 		    }
 		}
 	    }
@@ -513,7 +513,7 @@ xsltProcess(xmlDocPtr doc, xsltStylesheetPtr cur)
         }
     }
     if ((xslDebugStatus != DEBUG_RUN_RESTART) && (bytesWritten == -1))
-	xsldbgGenericErrorFunc(i18n("Error: Unable to save results of transformation to file %1.\n").arg((char *)optionsGetStringOption(OPTIONS_OUTPUT_FILE_NAME))); 
+	xsldbgGenericErrorFunc(i18n("Error: Unable to save results of transformation to file %1.\n").arg(xsldbgText(optionsGetStringOption(OPTIONS_OUTPUT_FILE_NAME)))); 
 }
 
 int
@@ -909,11 +909,7 @@ xsldbgLoadStylesheet()
 
     if (optionsGetIntOption(OPTIONS_TIMING))
         startTimer();
-#if LIBXML_VERSION >= 2006000
-    style = xmlSAXParseFile(&mySAXhdlr, (const char *) optionsGetStringOption(OPTIONS_SOURCE_FILE_NAME), 0);
-#else
     style = xmlParseFile((const char *) optionsGetStringOption(OPTIONS_SOURCE_FILE_NAME));
-#endif
     if (optionsGetIntOption(OPTIONS_TIMING))
         endTimer(i18n("Parsing stylesheet %1").arg((const char*)optionsGetStringOption(OPTIONS_SOURCE_FILE_NAME)));
     if (style == NULL) {
@@ -961,8 +957,13 @@ xmlDocPtr
 xsldbgLoadXmlData(void)
 {
     xmlDocPtr doc = NULL;
+    xmlSAXHandler mySAXHandler;
     doc = NULL;
 
+    xmlSAXVersion(&mySAXHandler,2);
+    oldGetEntity = mySAXHandler.getEntity;
+    mySAXHandler.getEntity = xsldbgGetEntity;
+
     if (optionsGetIntOption(OPTIONS_TIMING))
         startTimer();
 #ifdef LIBXML_HTML_ENABLED
@@ -979,8 +980,9 @@ xsldbgLoadXmlData(void)
                             NULL);
     else
 #endif
-#if LIBXML_VERSION >= 2006000
-        doc = xmlSAXParseFile(&xmlDefaultSAXHandler,
+
+#if LIBXML_VERSION >= 20600
+        doc = xmlSAXParseFile(&mySAXHandler,
 			     (char *) optionsGetStringOption(OPTIONS_DATA_FILE_NAME), 0);
 #else
         doc = xmlParseFile((char *) optionsGetStringOption(OPTIONS_DATA_FILE_NAME));
@@ -1085,7 +1087,7 @@ handler_routine(DWORD dwCtrlType)
             break;
     }
 
-    return (TRUE);
+    return (true);
 }
 
 #endif
@@ -1098,7 +1100,7 @@ void xsldbgStructErrorHandler(void * userData, xmlErrorPtr error)
 	if (getThreadStatus() != XSLDBG_MSG_THREAD_RUN){
 	    static const char *msgPrefix[4 + 1] = {"", "warning :", "error:", "fatal:"};
 	    if (error->file)
-		xsltGenericError(xsltGenericErrorContext, "%s%s in file %s line %d", msgPrefix[error->level], error->message, error->file, error->line);
+		xsltGenericError(xsltGenericErrorContext, "%s%s in file \"%s\" line %d", msgPrefix[error->level], error->message, error->file, error->line);
 	    else
 		xsltGenericError(xsltGenericErrorContext, "%s%s", msgPrefix[error->level], error->message);
 
@@ -1184,7 +1186,6 @@ xsldbgInit()
 
     if (!initialized) {
         sscanf(xmlParserVersion, "%d", &xmlVer);
-        xsldbgHasLineNumberFix = (xmlVer >= 20508);
         if (!debugInit()) {
 #ifdef WITH_XSLDBG_DEBUG_PROCESS
             xsltGenericError(xsltGenericErrorContext,
@@ -1221,7 +1222,7 @@ xsldbgInit()
         /* set up the parser */
         xmlInitParser();
 #if 0
-#if LIBXML_VERSION >= 2006000
+#if LIBXML_VERSION >= 20600
      xmlSetGenericErrorFunc(NULL,  NULL);
      xmlSetStructuredErrorFunc(NULL , (xmlStructuredErrorFunc)xsldbgStructErrorHandler);
 #else
@@ -1238,10 +1239,6 @@ xsldbgInit()
 	 */
 	xmlDefaultSAXHandlerInit();
 	xmlDefaultSAXHandler.cdataBlock = NULL;
-if (xsldbgHasLineNumberFix){
-	oldGetEntity = xmlDefaultSAXHandler.getEntity;
-	xmlDefaultSAXHandler.getEntity = xsldbgGetEntity;
-}
 
         if (getThreadStatus() != XSLDBG_MSG_THREAD_NOTUSED) {
             initialized = 1;
@@ -1251,7 +1248,7 @@ if (xsldbgHasLineNumberFix){
         /* catch SIGINT */
         oldHandler = signal(SIGINT, catchSigInt);
 #else
-        if (SetConsoleCtrlHandler(handler_routine, TRUE) != TRUE)
+        if (SetConsoleCtrlHandler(handler_routine, true) != true)
             return result;
 #endif
 
@@ -1280,7 +1277,7 @@ xsldbgFree()
     if (oldHandler != SIG_ERR)
         signal(SIGINT, oldHandler);
 #else
-    SetConsoleCtrlHandler(handler_routine, FALSE);
+    SetConsoleCtrlHandler(handler_routine, false);
 #endif
     initialized = 0;
 
@@ -1315,6 +1312,7 @@ xsldbgGenericErrorFunc(void *ctx, const char *msg, ...)
     va_start(args, msg);
     if (getThreadStatus() == XSLDBG_MSG_THREAD_RUN) {
         vsnprintf(msgBuffer, sizeof(msgBuffer), msg, args);
+
         notifyTextXsldbgApp(XSLDBG_MSG_TEXTOUT, msgBuffer);
     } else {
         xmlChar *encodeResult = NULL;
@@ -1332,14 +1330,23 @@ xsldbgGenericErrorFunc(void *ctx, const char *msg, ...)
 
 void xsldbgGenericErrorFunc(QString const &text)
 {
-    xsldbgGenericErrorFunc(0, text.utf8());
+    xsldbgGenericErrorFunc(0, "%s", text.utf8().data());
 }
 
 
 QString xsldbgUrl(const char *utf8fUrl)
 {
-    KURL url(QString::fromUtf8(utf8fUrl));
-    return url.prettyURL();
+    QString tempUrl(utf8fUrl);
+    QString fixedURI;
+    KURL url(tempUrl);
+
+    // May be provided with a URL that only has been encoded and has no protocol prefix ie a local file
+    if ( !tempUrl.startsWith("file:/")  &&  !tempUrl.startsWith("http:/") && !tempUrl.startsWith("ftp:/"))
+	fixedURI = KURL::decode_string(tempUrl);
+    else
+	fixedURI = url.prettyURL();
+
+    return fixedURI;
 }
 
 QString xsldbgUrl(const xmlChar *utf8Url)
@@ -1347,3 +1354,14 @@ QString xsldbgUrl(const xmlChar *utf8Url)
     return xsldbgUrl((const char*)(utf8Url));
 }
 
+QString xsldbgText(const char *utf8Text)
+{
+    return QString::fromUtf8(utf8Text);
+    
+}
+
+QString xsldbgText(const xmlChar *utf8Text)
+{
+    return QString::fromUtf8((const char *)utf8Text);
+}
+
