@@ -14,8 +14,8 @@
 
     You should have received a copy of the GNU Library General Public License
     along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-    Boston, MA 02111-1307, USA.
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 */
 
 #include <qcstring.h>
@@ -301,14 +301,14 @@ void Engine::upload( Entry *entry )
     } else {
       int result = KMessageBox::questionYesNo( mParentWidget, text, caption,
                                                i18n("Upload Info"),
-                                               i18n("&Close") );
+                                               KStdGuiItem::close() );
       if ( result == KMessageBox::Yes ) {
         kapp->invokeBrowser( noUploadUrl.url() );
       }
     }
   } else {
     int result = KMessageBox::questionYesNo( mParentWidget, text, caption,
-                                             i18n("&Upload"), i18n("&Cancel") );
+                                             i18n("&Upload"), KStdGuiItem::cancel() );
     if ( result == KMessageBox::Yes ) {
       KURL destination = mUploadProvider->uploadUrl();
       destination.setFileName( fi.fileName() );
@@ -401,8 +401,9 @@ void Engine::slotUploadPreviewJobResult( KIO::Job *job )
 
 void Engine::slotUploadMetaJobResult( KIO::Job *job )
 {
+  mUploadMetaFile = QString::null;
   if ( job->error() ) {
-    kdDebug(5850) << "Error uploading new stuff payload." << endl;
+    kdDebug(5850) << "Error uploading new stuff metadata." << endl;
     job->showErrorDialog( mParentWidget );
     emit uploadFinished( false );
     return;
