@@ -200,11 +200,13 @@ void QuantaDebuggerDBGp::setExecutionState(const QString &state)
   {
     setExecutionState(Stopping);
     emit updateStatus(DebuggerUI::Paused);
+    m_network.slotSocketDestroyed(); //XDebug disconnects when stopped and destroys our socket
   }
   else if(state == "stopped")
   {
     setExecutionState(Stopped);
     emit updateStatus(DebuggerUI::Paused);
+    m_network.slotSocketDestroyed(); //XDebug disconnects when stopped and destroys our socket
   }
   else if(state == "running")
   {
@@ -275,6 +277,7 @@ void QuantaDebuggerDBGp::processCommand(const QString& datas)
          || command == "step_into" 
          || command == "step_out")
     {
+      handleError(response);
       // If this is the acknoledge of a step command, request the call stack 
       m_network.sendCommand("stack_get");
       setExecutionState(attribute(response, "status"));
@@ -307,6 +310,8 @@ void QuantaDebuggerDBGp::processCommand(const QString& datas)
     
     else if(command == "property_set")
       propertySetResponse(response);
+    else if(command == "stop")
+      setExecutionState("stopped");
 
     // Unknown command...
     else
@@ -342,8 +347,12 @@ void QuantaDebuggerDBGp::initiateSession(const QDomNode& initpacket)
     endSession();
     return;
   }
-
-  debuggerInterface()->setActiveLine(mapServerPathToLocal(attribute(initpacket, "fileuri")), 0);
+  QString path = attribute(initpacket, "fileuri");
+  if (path.startsWith("file://"))
+  {
+    path.remove(0, 7);
+  }
+  debuggerInterface()->setActiveLine(mapServerPathToLocal(path), 0);
   
   // Store some vars
   m_initialscript = attribute(initpacket, "fileuri");
@@ -708,6 +717,10 @@ void QuantaDebuggerDBGp::showConfig(QDomNode node)
     {
       m_localBasedir = set.lineLocalBasedir->text();
       m_serverBasedir = set.lineServerBasedir->text();
+      if (!m_localBasedir.endsWith("/"))
+        m_localBasedir.append('/');
+      if (!m_serverBasedir.endsWith("/"))
+        m_serverBasedir.append('/');
     }
 
     el = node.namedItem("localbasedir").toElement();
